@@ -3,6 +3,7 @@ from urllib.parse import urlencode
 
 from django.conf import settings
 from django.contrib import auth, messages
+from django.contrib.auth.views import LogoutView
 from django.http import HttpResponseBadRequest, HttpResponseRedirect
 from django.shortcuts import resolve_url
 from django.urls import reverse
@@ -70,11 +71,6 @@ class DigiDAssertionConsumerServiceMockView(View):
         if url:
             return url
 
-        if hasattr(settings, "DIGID"):
-            digid_login_url = settings.DIGID.get("login_url")
-            if digid_login_url:
-                return resolve_url(digid_login_url)
-
         return resolve_url(settings.LOGIN_URL)
 
     def get_success_url(self):
@@ -104,3 +100,8 @@ class DigiDAssertionConsumerServiceMockView(View):
         auth.login(request, user)
 
         return HttpResponseRedirect(self.get_success_url())
+
+
+class DigiDLogoutMockView(LogoutView):
+    # in the future we can render a custom template to emulate Digid logout page
+    pass
